from cfgsaver import cfgsaver

pkg_name = 'cfgsaver_test'

def test_save():
	config = [{'name': 'Sophie', 'language': 'Python'}, {'name': 'Hildegard', 'language': 'PHP'}]
	assert cfgsaver.save(pkg_name, config) == True

def test_get():
	obj = cfgsaver.get(pkg_name)
	assert obj[0]['name'] == 'Sophie'


	
##print('hello')


__author__ = "Prahlad Yeri"
__email__ = "prahladyeri@yahoo.com"
__copyright__ = "(c) 2019 Prahlad Yeri"

__license__ = "MIT"
__version__ = "1.0.1"
__title__ = 'cfgsaver'
__description__ = 'Module to save and fetch configuration data in a standard path and format.'


"""
:title: cfgsaver
:author: Prahlad Yeri<prahladyeri@yahoo.com>
:license: MIT

This module is used to save and fetch configuration data in a standard path and format.
"""
import json, os

"""
Get Configuration Data

:param pkg_name: Name of the package
:param cfgpath, optional: Path to configuration directory
:returns: configuration data in dict
"""
def get(pkg_name , cfgpath=None):
	if cfgpath == None:
		cfgpath = os.path.expanduser("~/.config/%s" % pkg_name)
	if not os.path.isdir(cfgpath):
		os.makedirs(cfgpath)
		return {}
	cfgpath = os.path.join(cfgpath,  "cfg.json")
	if not os.path.isfile(cfgpath):
		return {}
	ss = open(cfgpath).read()
	return json.loads(ss)
	

"""
Save Configuration Data

:param pkg_name: Name of the package
:param cfgobject: Object to be saved (dict)
:param cfgpath, optional: Path to configuration directory
:returns: True
"""
def save(pkg_name, cfgobject, cfgpath=None):
	if cfgpath == None:
		cfgpath = os.path.expanduser("~/.config/%s" % pkg_name)
	if not os.path.isdir(cfgpath):
		os.makedirs(cfgpath)
	cfgpath = os.path.join(cfgpath,  "cfg.json")
	ss = json.dumps(cfgobject)
	open(cfgpath, 'w').write(ss)
	return True

"""
Prompt user for configuration keys and save resulting values in the configuration.

:param pkg_name: Name of the package
:param keys: List of keys
:param cfgpath, optional: Path to json file
:returns: True
"""
def get_from_cmd(pkg_name, keys, cfgobject):
	return True


#!/usr/bin/env python3
import os, sys
import cfgsaver
from cfgsaver import __version__, __description__, __author__, __email__, __license__, __title__
from setuptools import setup, find_packages
from setuptools.command.install import install
#from subprocess import check_call
#from pkg_resources import Requirement, resource_filename
from distutils.dir_util import copy_tree
#import shutil

app_name = "cfgsaver"
pkg_name = "cfgsaver"

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

s = setup(
	name=app_name,
	version=__version__,
	license=__license__,
	description=__description__,
	long_description=read("README.md"),
	long_description_content_type='text/markdown',
	url='https://github.com/prahladyeri/%s' % app_name,
	packages=find_packages(),
	include_package_data=True,
	install_requires=[],
	python_requires = ">= 3.4",
	author=__author__,
	author_email=__email__,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
	)

